@@ -663,7 +663,7 @@ class TypeConverter(object):
 class AstBuilder(object):
 
     def __init__(self, token_stream, filename, in_class='', visibility=None,
-                 namespace_stack=None):
+                 namespace_stack=None, quiet=False):
         if namespace_stack is None:
             namespace_stack = []
 
@@ -674,6 +674,7 @@ class AstBuilder(object):
         # Using a deque should be even better since we access from both sides.
         self.token_queue = []
         self.namespace_stack = namespace_stack[:]
+        self.quiet = quiet
         self.in_class = in_class
         if in_class is None:
             self.in_class_name_only = None
@@ -687,9 +688,10 @@ class AstBuilder(object):
         self.converter = TypeConverter(self.namespace_stack)
 
     def handle_error(self, msg, token):
-        printable_queue = list(reversed(self.token_queue[-20:]))
-        sys.stderr.write('Got %s in %s @ %s %s\n' %
-                         (msg, self.filename, token, printable_queue))
+        if not self.quiet:
+            printable_queue = list(reversed(self.token_queue[-20:]))
+            sys.stderr.write('Got %s in %s @ %s %s\n' %
+                             (msg, self.filename, token, printable_queue))
 
     def generate(self):
         while True:
@@ -752,7 +754,7 @@ class AstBuilder(object):
             # Handle data or function declaration/definition.
             syntax = tokenize.SYNTAX
             temp_tokens, last_token = \
-                self._get_var_tokens_up_to(syntax, '(', ';', '{', '[', '}')
+                self._get_var_tokens_up_to(syntax, '(', ';', '{', '}')
             if last_token.name == '}':
                 return None
 
@@ -771,17 +773,6 @@ class AstBuilder(object):
                         temp_tokens.extend(new_temp)
                         break
 
-            if last_token.name == '[':
-                # Handle array, this isn't a method, unless it's an operator.
-                # TODO(nnorwitz): keep the size somewhere.
-                temp_tokens.append(last_token)
-                if temp_tokens[-2].name == 'operator':
-                    temp_tokens.append(self._get_next_token())
-                else:
-                    temp_tokens2, last_token = \
-                        self._get_var_tokens_up_to(tokenize.SYNTAX, ';')
-                    temp_tokens.extend(temp_tokens2)
-
             if last_token.name == ';':
                 # Handle data, this isn't a method.
                 name, type_name, templated_types, modifiers, default, _ = \
@@ -864,8 +855,14 @@ class AstBuilder(object):
     def _get_var_tokens_up_to(self, expected_token_type, *expected_tokens):
         last_token = self._get_next_token()
         tokens = []
-        while (last_token.token_type != expected_token_type or
+        count = 0
+        while (count != 0 or
+               last_token.token_type != expected_token_type or
                last_token.name not in expected_tokens):
+            if last_token.name == '[':
+                count += 1
+            elif last_token.name == ']':
+                count -= 1
             tokens.append(last_token)
             last_token = self._get_next_token()
         return tokens, last_token
@@ -988,15 +985,10 @@ class AstBuilder(object):
             del return_type_and_name[index:]
             name = return_type_and_name.pop()
         elif name.name == ']':
-            rt = return_type_and_name
-            assert_parse(rt[-1].name == '[', return_type_and_name)
-            assert_parse(rt[-2].name == 'operator', return_type_and_name)
-            name_seq = return_type_and_name[-2:]
+            name_seq = return_type_and_name[-2]
             del return_type_and_name[-2:]
-            name = tokenize.Token(tokenize.NAME, 'operator[]',
-                                  name_seq[0].start, name.end)
-            # Get the open paren so _get_parameters() below works.
-            self._get_next_token()
+            name = tokenize.Token(tokenize.NAME, name_seq.name + '[]',
+                                  name_seq.start, name.end)
 
         # TODO(nnorwitz): store template_portion.
         return_type = return_type_and_name
@@ -1596,7 +1588,8 @@ class AstBuilder(object):
         body = None
         if token.token_type == tokenize.SYNTAX and token.name == '{':
             ast = AstBuilder(self.get_scope(), self.filename, class_name,
-                             visibility, self.namespace_stack)
+                             visibility, self.namespace_stack,
+                             quiet=self.quiet)
             body = list(ast.generate())
 
             if not self._handling_typedef:
@@ -1723,7 +1716,7 @@ class AstBuilder(object):
         self._ignore_up_to(tokenize.SYNTAX, ';')
 
 
-def builder_from_source(source, filename):
+def builder_from_source(source, filename, quiet=False):
     """Utility method that returns an AstBuilder from source code.
 
     Args:
@@ -1734,7 +1727,9 @@ def builder_from_source(source, filename):
       AstBuilder
 
     """
-    return AstBuilder(tokenize.get_tokens(source), filename)
+    return AstBuilder(tokenize.get_tokens(source, quiet=quiet),
+                      filename,
+                      quiet=quiet)
 
 
 def assert_parse(value, message):
